@@ -122,6 +122,9 @@ static void vcc_detach(ENTRY *entry)
 {
     ENTRY *walk;
 
+    /* immediately try to bring it up again if this was the connection to the
+       ATMARP server and we still need it. Should delay this in case the ARP
+       server has a real problem. @@@ */
     if (entry->itf && entry->itf->arp_srv == entry)
 	for (walk = entry->itf->table; walk; walk = walk->next) {
 	    if (walk->state == as_resolv) break;
@@ -478,6 +481,8 @@ static void learn(VCC *vcc,unsigned long ip,struct sockaddr_atmsvc *addr)
 	    Q_INSERT_HEAD(entry->vccs,vcc);
 	}
     }
+    if (entry->state == as_valid && entry->ip == ip && entry->addr &&
+      atm_equal(entry->addr,addr,0,0)) return; /* no news */
     STOP_TIMER(entry);
     entry->ip = ip;
     if (!entry->itf) {
@@ -922,14 +927,6 @@ void disconnect_vcc(VCC *vcc)
     ENTRY *entry;
 
     diag(COMPONENT,DIAG_DEBUG,"disconnected VCC0x%08x",(unsigned long) vcc);
-    /* immediately try to bring it up again if this was the connection to the
-       ATMARP server and we still need it. Should delay this in case the ARP
-       server has a real problem. @@@ */
-    if (vcc->entry && vcc->entry->itf && (vcc->entry->flags & ATF_ARPSRV)) {
-	for (entry = vcc->entry->itf->table; entry; entry = entry->next)
-	   if (entry->state == as_resolv) break;
-	if (entry) want_arp_srv(vcc->entry->itf);
-    }
     entry = vcc->entry;
     discard_vcc(vcc);
     if (entry) vcc_detach(entry);
