@@ -1,6 +1,6 @@
 /* atmarpd.c - ATMARP demon */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdlib.h>
@@ -36,11 +36,13 @@ ITF *itfs = NULL;
 ENTRY *unknown_incoming = NULL;
 int debug;
 int pretty = A2T_PRETTY | A2T_NAME;
+int merge = 0;
 
 
 static void usage(const char *name)
 {
-    fprintf(stderr,"usage: %s [ -b ] [ -d ] [ -l logfile ] [ -n ]\n",name);
+    fprintf(stderr,"usage: %s [ -b ] [ -d ] [ -l logfile ] [ -m ] [ -n ]\n",
+      name);
     exit(1);
 }
 
@@ -58,7 +60,7 @@ int main(int argc,char **argv)
     set_verbosity(NULL,DIAG_INFO);
     dump_dir = DUMP_DIR;
     background = 0;
-    while ((c = getopt(argc,argv,"bdD:l:np")) != EOF)
+    while ((c = getopt(argc,argv,"bdD:l:mnp")) != EOF)
 	switch (c) {
 	    case 'b':
 		background = 1;
@@ -73,6 +75,9 @@ int main(int argc,char **argv)
 	    case 'l':
 		set_logfile(optarg);
 		break;
+	    case 'm':
+		merge = 1;
+		break;
 	    case 'n': /* @@@ was planned for NSAP matching */
 		pretty = A2T_PRETTY;
 		break;
