@@ -1,6 +1,6 @@
 /* table.c - ATMARP table */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdio.h>
@@ -55,11 +55,17 @@ ENTRY *lookup_addr(const ITF *itf,const struct sockaddr_atmsvc *addr)
     ENTRY *walk;
 
     for (walk = itf->table; walk; walk = walk->next)
-	if (walk->addr && (*walk->addr->sas_addr.prv ? *addr->sas_addr.prv &&
-	  !memcmp(addr->sas_addr.prv,walk->addr->sas_addr.prv,ATM_ESA_LEN) :
-	  !*addr->sas_addr.prv) && ((*walk->addr->sas_addr.pub ?
-	  *addr->sas_addr.pub && !strcmp(addr->sas_addr.pub,
-	  walk->addr->sas_addr.pub) : !*addr->sas_addr.pub))) break;
+	if (walk->addr && atm_equal(walk->addr,addr,0,0)) break;
+    return walk;
+}
+
+
+ENTRY *lookup_incoming(const struct sockaddr_atmsvc *addr)
+{
+    ENTRY *walk;
+
+    for (walk = unknown_incoming; walk; walk = walk->next)
+	if (walk->addr && atm_equal(walk->addr,addr,0,0)) break;
     return walk;
 }
 
