@@ -58,10 +58,9 @@ Message *create_poll_message(void)
 
   AsnListInit(poll_message->data->a.get_next_request->variable_bindings, sizeof(VarBind));
   entry = AppendVarBind(poll_message->data->a.get_next_request->variable_bindings);
-  entry->name.octs = alloc(ADDRESS_LEN + 1);
-  entry->name.octetLen = ADDRESS_LEN + 1;
+  entry->name.octs = alloc(ADDRESS_LEN);
+  entry->name.octetLen = ADDRESS_LEN;
   memcpy(entry->name.octs, ADDRESS_OID, ADDRESS_LEN);
-  entry->name.octs[ADDRESS_LEN] = '\0';
   entry->value = alloc_t(ObjectSyntax);
   entry->value->choiceId = OBJECTSYNTAX_SIMPLE;
   entry->value->a.simple = alloc_t(SimpleSyntax);
@@ -90,11 +89,10 @@ Message *create_set_message(void)
   AsnListInit(set_message->data->a.set_request->variable_bindings, sizeof(VarBind));
   entry = AppendVarBind(set_message->data->a.set_request->variable_bindings);
   /* Allocate enough memory to hold the largest possible address */
-  entry->name.octs = alloc(ADDRESS_LEN + 42);
-  entry->name.octetLen = ADDRESS_LEN + 2;
+  entry->name.octs = alloc(ADDRESS_LEN + 41);
+  entry->name.octetLen = ADDRESS_LEN + 1;
   memcpy(entry->name.octs, ADDRESS_OID, ADDRESS_LEN);
-  entry->name.octs[ADDRESS_LEN] = '\0'; /* Local UNI */
-  entry->name.octs[ADDRESS_LEN + 1] = '\24'; /* 20 octet address */
+  entry->name.octs[ADDRESS_LEN] = '\24'; /* 20 octet address */
   entry->value = alloc_t(ObjectSyntax);
   entry->value->choiceId = OBJECTSYNTAX_SIMPLE;
   entry->value->a.simple = alloc_t(SimpleSyntax);
