@@ -1,6 +1,6 @@
 /* atmarp.c - RFC1577 ATMARP control */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
 
 
 #include <stdlib.h>
@@ -58,7 +58,7 @@ static void usage(const char *name)
     fprintf(stderr,"%6s %s -c [[atm]N]\n","",name);
     fprintf(stderr,"%6s %s -q ip_addr qos_spec\n","",name);
     fprintf(stderr,"%6s %s -s ip_addr [itf.]vpi.vci [pcr value] [qos spec] "
-      "[temp] [pub] [null]\n","",name);
+      "[temp] [pub]\n%8s [null]\n","",name,"");
     fprintf(stderr,"%6s %s -s ip_addr atm_addr [pcr value] [qos spec] [temp] "
       "[pub] [arpsrv]\n","",name);
     fprintf(stderr,"%6s %s -d ip_addr [arpsrv]\n","",name);
@@ -189,6 +189,7 @@ int main(int argc,char **argv)
 	if (optind+2 < argc || strcmp(argv[optind+1],"arpsrv")) usage(argv[0]);
 	req.arp_flags |= ATF_ARPSRV;
     }
+    if (!req.arp_qos.aal) req.arp_qos.aal = ATM_AAL5;
     if ((s = socket(AF_INET,SOCK_DGRAM,0)) < 0) {
 	perror("socket");
 	return 1;
