@@ -1,6 +1,6 @@
 /* clip.c - CLassical IP over ATM control (to be replaced by ATMARP) */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
 
 
 #include <stdlib.h>
@@ -40,7 +40,7 @@ int main(int argc,char **argv)
 	    argv++;
 	}
     if (argc != 2 && argc != 3) usage(name);
-    if ((s = socket(PF_ATMPVC,SOCK_DGRAM,ATM_AAL5)) < 0) {
+    if ((s = socket(PF_ATMPVC,SOCK_DGRAM,0)) < 0) {
 	perror("socket");
 	return 1;
     }
@@ -48,6 +48,7 @@ int main(int argc,char **argv)
     if (text2atm(argv[1],(struct sockaddr *) &addr,sizeof(addr),T2A_PVC) < 0)
 	usage(argv[0]);
     memset(&qos,0,sizeof(qos));
+    qos.aal = ATM_AAL5;
     if (argc != 3) qos.txtp.traffic_class = ATM_UBR;
     else {
 	qos.txtp.traffic_class = ATM_CBR;
