@@ -9,10 +9,7 @@
 #include <linux/atm.h>
 
 #include "atm.h"
-
-
-#define TRY_OTHER -2
-#define FATAL	  -1 /* must be -1 */
+#include "atmres.h"
 
 
 static int put_item(char **buffer,int *length,int value)
@@ -188,6 +185,9 @@ int atm2text(char *buffer,int length,const struct sockaddr *addr,int flags)
     if (!length) return -1;
     if (flags & A2T_NAME) {
 	result = try_name(buffer,length,addr);
+	if (result == TRY_OTHER && !(flags & A2T_LOCAL))
+	    result = ans_byaddr(buffer,length,
+	      (const struct sockaddr_atmsvc *) addr,flags);
 	if (result == FATAL) return FATAL;
 	if (result != TRY_OTHER) return strlen(buffer);
     }
