@@ -8,10 +8,10 @@
 
 /*--------------------------- Common definitions ----------------------------*/
 
+#include <stdio.h>
 #include <sys/types.h>
 #include <sys/time.h>
 
-
 /* doubly linked list primitives */
  
 #define Q_INSERT_HEAD(r,i) ({ (i)->next = r; (i)->prev = NULL; \
@@ -54,8 +54,12 @@ void set_application(const char *name);
 
 void set_logfile(const char *name);
 
+FILE *get_logfile(void);
+
 void set_verbosity(const char *component,int level);
 
+int get_verbosity(const char *component);
+
 void vdiag(const char *component,int severity,const char *fmt,va_list ap);
 void diag(const char *component,int severity,const char *fmt,...);
 
