@@ -25,6 +25,7 @@
 
 /* Message types */
 
+#define QMSG_NATIONAL		0x00	/* National specific message escape */
 #define QMSG_SETUP		0x05	/* SETUP */
 #define QMSG_ALERTING		0x01	/* ALERTING */
 #define QMSG_CALL_PROC		0x02	/* CALL PROCEEDING */
@@ -43,6 +44,7 @@
 #define QMSG_PARTY_ALERT	0x85	/* PARTY ALERTING */
 #define QMSG_DROP_PARTY		0x83	/* DROP PARTY */
 #define QMSG_DROP_PARTY_ACK	0x84	/* DROP PARTY ACKNOWLEDGE */
+#define QMSG_RESERVED		0xff	/* reserved for EVEN MORE msg types */
 
 /* Information element identifiers */
 
