@@ -1,6 +1,6 @@
 /* qlib.c - run-time library */
  
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
  
 
 #ifdef DUMP_MODE
@@ -158,8 +158,19 @@ void PREFIX(start)(void)
 static int q_init(Q_DSC *dsc)
 {
     size_t bytes;
+    int i;
 
+    /* initialize verything in case anything goes wrong during allocations. */
+    dsc->errors = NULL;
+    dsc->field_present = NULL;
+    dsc->group_present = NULL;
+    dsc->data = NULL;
+    dsc->required = NULL;
+    dsc->length = NULL;
+    dsc->field_map = NULL;
+    dsc->group_map = NULL;
     dsc->data = malloc((size_t) Q_DATA_BYTES);
+    dsc->error = 1;
     if (!dsc->data) {
 	perror("out of memory");
 	return -1;
@@ -194,8 +205,19 @@ static int q_init(Q_DSC *dsc)
 	}
 	memset(dsc->length,0,sizeof(int)*Q_VARLEN_FIELDS);
     }
+    dsc->field_map = malloc(sizeof(int)*Q_FIELDS);
+    if (!dsc->field_map) {
+	perror("out of memory");
+	return -1;
+    }
+    for (i = 0; i < Q_FIELDS; i++) dsc->field_map[i] = i;
+    dsc->group_map = malloc(sizeof(int)*Q_GROUPS);
+    if (!dsc->group_map) {
+	perror("out of memory");
+	return -1;
+    }
+    for (i = 0; i < Q_GROUPS; i++) dsc->group_map[i] = i;
     dsc->error = 0;
-    dsc->errors = NULL;
     return 0;
 }
 
@@ -221,6 +243,7 @@ void q_assign(Q_DSC *dsc,int field,unsigned long value)
 
     if (field < 0 || field >= Q_FIELDS)
 	PREFIX(report)(Q_FATAL,"invalid field value (%d)",field);
+    field = dsc->field_map[field];
     if (!fields[field].values) {
 	if (q_test(dsc->field_present,field)) /* probably an error ... */
 	    PREFIX(report)(Q_ERROR,"changing field %d",field);
@@ -248,6 +271,7 @@ void q_write(Q_DSC *dsc,int field,const void *buf,int size)
 {
     if (field < 0 || field >= Q_FIELDS)
 	PREFIX(report)(Q_FATAL,"invalid field value (%d)",field);
+    field = dsc->field_map[field];
     if (fields[field].pos & 7)
 	PREFIX(report)(Q_FATAL,"invalid use of q_write (%d)",field);
     if (fields[field].actual >= 0) {
@@ -273,11 +297,15 @@ int q_present(const Q_DSC *dsc,int field)
     if (field < 0) {
 	if (field < -Q_GROUPS)
 	    PREFIX(report)(Q_FATAL,"invalid group number (%d)",field);
-	return q_test((unsigned char *) dsc->group_present,-field-1);
+	if (!dsc->group_present) return 0;
+	field = dsc->group_map[-field-1];
+	return q_test((unsigned char *) dsc->group_present,field);
     }
     else {
 	if (field >= Q_FIELDS)
 	    PREFIX(report)(Q_FATAL,"invalid field number (%d)",field);
+	if (!dsc->field_present) return 0;
+	field = dsc->field_map[field];
 	if (q_test(dsc->field_present,field)) return 1;
 	return q_test((unsigned char *) dsc->group_present,
 	  fields[field].parent);
@@ -289,6 +317,7 @@ unsigned long q_fetch(const Q_DSC *dsc,int field)
 {
     if (field < 0 || field >= Q_FIELDS)
 	PREFIX(report)(Q_FATAL,"invalid field value (%d)",field);
+    field = dsc->field_map[field];
     return q_get(dsc->data,fields[field].pos,fields[field].size);
 }
 
@@ -297,6 +326,7 @@ int q_length(const Q_DSC *dsc,int field)
 {
     if (field < 0 || field >= Q_FIELDS)
 	PREFIX(report)(Q_FATAL,"invalid field value (%d)",field);
+    field = dsc->field_map[field];
     if (fields[field].pos & 7)
 	PREFIX(report)(Q_FATAL,"invalid use of q_length (%d)",field);
     if (fields[field].actual < 0)
@@ -311,6 +341,7 @@ int q_read(Q_DSC *dsc,int field,void *buf,int size)
 
     if (field < 0 || field >= Q_FIELDS)
 	PREFIX(report)(Q_FATAL,"invalid field value (%d)",field);
+    field = dsc->field_map[field];
     if (fields[field].pos & 7)
 	PREFIX(report)(Q_FATAL,"invalid use of q_read (%d)",field);
     if (fields[field].actual >= 0) len = dsc->length[fields[field].actual];
@@ -328,6 +359,11 @@ int q_read(Q_DSC *dsc,int field,void *buf,int size)
 }
 
 
+void q_instance(Q_DSC *dsc,int group)
+{
+}
+
+
 static int q_compose(Q_DSC *dsc,unsigned char *buf,int size)
 {
     LEN_BUF stack[LENGTH_STACK];
@@ -461,6 +497,10 @@ static void handle_error(Q_DSC *dsc,int size,unsigned char *buf,
       *sp,*rp,*pos-buf,*end-buf);
     error = alloc_t(Q_ERR_DSC);
     error->type = type;
+    for (last = &dsc->errors; *last; last = &(*last)->next);
+    *last = error;
+    error->next = NULL;
+    if (!pc) return;
     error->pc = *pc-parse;
     error->offset = *pos-buf;
     error->value = value;
@@ -483,9 +523,6 @@ static void handle_error(Q_DSC *dsc,int size,unsigned char *buf,
 	*pc = parse+sizeof(parse)/sizeof(*parse)-1;
 	*pos = buf+size;
     }
-    for (last = &dsc->errors; *last; last = &(*last)->next);
-    *last = error;
-    error->next = NULL;
 }
 
 
@@ -533,7 +570,7 @@ static int _q_parse(Q_DSC *dsc,unsigned char *buf,int size)
 		    }
 		    else {
 			for (i = 0; i < len/8; i++)
-			    DUMP(" %02x",pos[pc[1]/8+i]);
+			    DUMP(" %02x",pos[i]);
 			DUMP("\n");
 		    }
 		}
@@ -617,6 +654,11 @@ static int _q_parse(Q_DSC *dsc,unsigned char *buf,int size)
 			if (*pc != value && *pc != -1) pc += 3;
 			else {
 			    pc++;
+			    if (*pc != -1 && q_test((unsigned char *)
+			      dsc->group_present,*pc)) {
+				pc += 2;
+				continue;
+			    }
 			    for (group = *pc++; group != -1; group =
 			      groups[group].parent)
 				q_set((unsigned char *) dsc->group_present,
@@ -717,8 +759,15 @@ static int q_parse(Q_DSC *dsc,unsigned char *buf,int size)
 
 int PREFIX(open)(Q_DSC *dsc,void *buf,int size)
 {
+    int error;
+
     dsc->buffer = NULL;
-    q_init(dsc);
+    error = q_init(dsc);
+    if (error) {
+	handle_error(dsc,size,buf,NULL,NULL,NULL,NULL,NULL,NULL,NULL,qet_init,
+	  0);
+	return error;
+    }
     return q_parse(dsc,buf,size);
 }
 
@@ -729,8 +778,7 @@ int q_create(Q_DSC *dsc,void *buf,int size)
 {
    dsc->buffer = buf;
    dsc->buf_size = size;
-   q_init(dsc);
-   return 0;
+   return q_init(dsc);
 }
 
 #endif
@@ -744,11 +792,13 @@ int PREFIX(close)(Q_DSC *dsc)
     if (dsc->buffer && !dsc->error)
 	size = q_compose(dsc,dsc->buffer,dsc->buf_size);
 #endif
-    free(dsc->data);
-    free(dsc->required);
-    free(dsc->field_present);
-    free(dsc->group_present);
+    if (dsc->data) free(dsc->data);
+    if (dsc->required) free(dsc->required);
+    if (dsc->field_present) free(dsc->field_present);
+    if (dsc->group_present) free(dsc->group_present);
     if (dsc->length) free(dsc->length);
+    if (dsc->field_map) free(dsc->field_map);
+    if (dsc->group_map) free(dsc->group_map);
     while (dsc->errors) {
 	Q_ERR_DSC *next;
 
