@@ -1,6 +1,6 @@
 /* trace.c - Support functions for message tracing */
  
-/* Written 1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1996,1997 by Werner Almesberger, EPFL-LRC */
  
 
 #include <stdlib.h>
@@ -192,7 +192,7 @@ static void print_kernel(void *msg,int size)
 	error = strerror(m->reply > 0 ? m->reply : -m->reply);
 	append(" (%s)",error ? error : "???");
     }
-    append(", aal %d\n",m->aal);
+    append(", aal %d\n",m->qos.aal);
     append("  pvc %d.%d.%d\n",m->pvc.sap_addr.itf,m->pvc.sap_addr.vpi,
       m->pvc.sap_addr.vci);
     append("  local ");
