@@ -1,6 +1,6 @@
 /* bw.c - block write */
 
-/* Written 1995,1996 by Werner Almesberger, EPFL-LRC */
+/* Written 1995-1997 by Werner Almesberger, EPFL-LRC */
 
 
 #include <stdlib.h>
@@ -35,7 +35,7 @@ int main(int argc,char **argv)
     if (argc != 2 && argc != 3) usage(argv[0]);
     if (argc == 2) blocks = 0;
     else blocks = atoi(argv[2]);
-    if ((s = socket(PF_ATMPVC,SOCK_DGRAM,ATM_AAL5)) < 0) {
+    if ((s = socket(PF_ATMPVC,SOCK_DGRAM,0)) < 0) {
 	perror("socket");
 	return 1;
     }
@@ -43,6 +43,7 @@ int main(int argc,char **argv)
     if (text2atm(argv[1],(struct sockaddr *) &addr,sizeof(addr),T2A_PVC) < 0)
 	usage(argv[0]);
     memset(&qos,0,sizeof(qos));
+    qos.aal = ATM_AAL5;
     qos.txtp.traffic_class = ATM_UBR;
     qos.txtp.max_sdu = BSIZE;
     if (setsockopt(s,SOL_ATM,SO_ATMQOS,&qos,sizeof(qos)) < 0) {
