@@ -322,6 +322,7 @@ int no_check = 0;
 		}
 	}
 	if (arequipa && !udp) qos.rxtp = qos.txtp;
+	if (!qos.aal) qos.aal = ATM_AAL5;
     }
     if (!atm && trans)  {
 	/* xmitr */
@@ -387,7 +388,7 @@ int no_check = 0;
     }
 
     if ((fd = socket(atm ? satm.sas_family : AF_INET,
-        udp?SOCK_DGRAM:SOCK_STREAM, atm ? ATM_AAL5 : 0)) < 0) err("socket");
+        udp?SOCK_DGRAM:SOCK_STREAM,0)) < 0) err("socket");
     
     mes("socket");
 	if (arequipa && trans) {
